@@ -46,7 +46,7 @@ public:
   virtual ~sql_error() throw () {}
 
   /// The query whose execution triggered the exception
-  const PGSTD::string &query() const { return m_Q; }
+  const PGSTD::string &query() const { return m_Q; }			//[t56]
 };
 
 
