@@ -121,6 +121,14 @@ public:
     inline const char *Name() const;					//[t11]
 
     /// Read value into Obj; or leave Obj untouched & return false if null
+    /** Caution: the conversion is done using the currently active locale, 
+     * whereas PostgreSQL delivers values in the "default" (C) locale.  This 
+     * means that if you intend to use this function from a locale that doesn't
+     * understand the data types in question (particularly numeric types like 
+     * float and int) in default C format, you'll need to switch back to the C 
+     * locale before the call. 
+     * This should be fixed at some point in the future.
+     */
     template<typename T> bool to(T &Obj) const				//[t1]
     {
       if (is_null())
@@ -162,6 +170,16 @@ public:
       return NotNull;
     }
 
+    /// Return value as object of given built-in type, or Default if null
+    /** Note that unless the function is instantiated with an explicit template
+     * argument, the Default value also determines the result type.
+     */
+    template<typename T> T as(const T &Default) const			//[t45]
+    {
+      T Obj;
+      return to(Obj) ? Obj : Default;
+    }
+
     bool is_null() const { return m_Home->GetIsNull(m_Index,m_Col); }	//[t12]
 
     size_type size() const { return m_Home->GetLength(m_Index,m_Col); }	//[t11]
