@@ -52,6 +52,13 @@ template<> inline const char *FmtString(unsigned char) { return  "%c"; }
 
 
 /// Convert object of built-in type to string
+/** Caution: the conversion is done using the currently active locale, whereas
+ * PostgreSQL expects values in the "default" (C) locale.  This means that if
+ * you intend to use this function from a locale that renders the data types in
+ * question (particularly numeric types like float and int) differently from the
+ * C default, you'll need to switch back to the C locale before the call.
+ * This should be fixed at some point in the future.
+ */
 template<typename T> inline PGSTD::string ToString(const T &Obj)
 {
   // TODO: Find a decent way to determine max string length at compile time!
@@ -80,6 +87,14 @@ template<> inline PGSTD::string ToString(const unsigned short &Obj)
 }
 
 
+/// Convert string to object of built-in type
+/** Caution: the conversion is done using the currently active locale, whereas
+ * PostgreSQL delivers values in the "default" (C) locale.  This means that if
+ * you intend to use this function from a locale that doesn't understand the 
+ * data types in question (particularly numeric types like float and int) in
+ * default C format, you'll need to switch back to the C locale before the call.
+ * This should be fixed at some point in the future.
+ */
 template<typename T> inline void FromString(const char Str[], T &Obj)
 {
   if (!Str) throw PGSTD::runtime_error("Attempt to convert NULL string to " +
@@ -245,7 +260,7 @@ template<typename T> PGSTD::string Classname(const T *);
  * used to free the memory.  If not, free() is used instead.  This matters on
  * Windows, where memory allocated by a DLL must be freed by the same DLL.
  */
-template<typename T> class PQAlloc
+template<typename T> class PQXX_LIBEXPORT PQAlloc
 {
   T *m_Obj;
 public:
@@ -301,7 +316,7 @@ private:
   void freemem() throw ()
   {
 #ifdef HAVE_PQFREEMEM
-    PQfreemem(m_Obj);
+    PQfreemem(reinterpret_cast<unsigned char *>(m_Obj));
 #else
     free(m_Obj);
 #endif
@@ -319,7 +334,7 @@ private:
 /// for the guest type, and that GUEST::Name() returns a user-readable name for
 /// the GUEST object.
 template<typename GUEST>
-class Unique
+class PQXX_LIBEXPORT Unique
 {
 public:
   Unique() : m_Guest(0) {}
