@@ -138,22 +138,26 @@ int main(int argc, char *argv[])
     {
       dstC.Perform(CreateTable(dstTable));
     } 
-    catch (const exception &)
+    catch (const sql_error &)
     {
     }
 
     dstC.Perform(ClearTable(dstTable));
     dstC.Perform(CopyTable(orgTrans, orgTable, dstTable));
   }
+  catch (const sql_error &e)
+  {
+    cerr << "SQL error: " << e.what() << endl
+         << "Query was: '" << e.query() << "'" << endl;
+    return 1;
+  }
   catch (const exception &e)
   {
-    // All exceptions thrown by libpqxx are derived from std::exception
     cerr << "Exception: " << e.what() << endl;
     return 2;
   }
   catch (...)
   {
-    // This is really unexpected (see above)
     cerr << "Unhandled exception" << endl;
     return 100;
   }
