@@ -144,6 +144,12 @@ int main(int argc, char *argv[])
 		        "despite abort.  This could be a bug in libpqxx, "
 			"or something else modified the table.");
   }
+  catch (const sql_error &e)
+  {
+    cerr << "SQL error: " << e.what() << endl
+         << "Query was: '" << e.query() << "'" << endl;
+    return 1;
+  }
   catch (const exception &e)
   {
     // All exceptions thrown by libpqxx are derived from std::exception
