@@ -57,10 +57,8 @@ int main(int, char *argv[])
 
     // Count rows.
     Result R( T.Exec("SELECT count(*) FROM " + Table) );
-    int Rows;
-    R.at(0).at(0).to(Rows);
 
-    if (Rows <= 10) 
+    if (R.at(0).at(0).as(0) <= 10) 
       throw runtime_error("Not enough rows in '" + Table + "' "
 		          "for serious testing.  Sorry.");
 
